@@ -4,7 +4,7 @@
 #  Distributed under the terms of the 3-clause BSD License.
 #-----------------------------------------------------------------------------
 
-__version__ = '0.5.1'
+__version__ = '0.6.0'
 
 import sys
 import platform
@@ -16,10 +16,10 @@ if sys.platform == "darwin":
     else:
         from ._mac_detect import *
     del V
-elif sys.platform == "win32" and int(platform.release()) >= 10:
+elif sys.platform == "win32" and platform.release().isdigit() and int(platform.release()) >= 10:
     # Checks if running Windows 10 version 10.0.14393 (Anniversary Update) OR HIGHER. The getwindowsversion method returns a tuple.
     # The third item is the build number that we can use to check if the user has a new enough version of Windows.
-    winver = int(sys.getwindowsversion()[2])
+    winver = int(platform.version().split('.')[2])
     if winver >= 14393:
         from ._windows_detect import *
     else:
@@ -29,4 +29,4 @@ elif sys.platform == "linux":
 else:
     from ._dummy import *
 
-del sys, platform
\ No newline at end of file
+del sys, platform
